/*******************************************************************************
* File Name: isr_1.c  
* Version 1.50
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <isr_1.H>
#include <device.h>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START isr_1_intc` */
#define ECHO_POINTER_OFFSET_VALUE 6000
extern uint32 output_audio_val; // PseudoPointer to 8 bit output value used by the VDAC
extern uint32 latest_input_val; //PseudoPointer to latest acquired 8 bit ADC value from microphone
extern uint32 audio_circ_buffer_ptr_index; //Keeps track of the circular buffer index on audio data
extern uint32 echo_ptr_offset; //Pointer index to locate delayed data for echo, same can be done for flanger
extern uint32 echo_data; // PseudoPointer to delayed data
extern uint8 ndex;
extern uint8 DMA_3_Chan;
/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE	16
#endif
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);

/*******************************************************************************
* Function Name: isr_1_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void isr_1_Start(void)
{
    /* For all we know the interrupt is active. */
    isr_1_Disable();

    /* Set the ISR to point to the isr_1 Interrupt. */
    isr_1_SetVector(isr_1_Interrupt);

    /* Set the priority. */
    isr_1_SetPriority(isr_1_INTC_PRIOR_NUMBER);

    /* Enable it. */
    isr_1_Enable();
}

/*******************************************************************************
* Function Name: isr_1_StartEx
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*******************************************************************************/
void isr_1_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    isr_1_Disable();

    /* Set the ISR to point to the isr_1 Interrupt. */
    isr_1_SetVector(address);

    /* Set the priority. */
    isr_1_SetPriority(isr_1_INTC_PRIOR_NUMBER);

    /* Enable it. */
    isr_1_Enable();
}

/*******************************************************************************
* Function Name: isr_1_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void isr_1_Stop(void) 
{
    /* Disable this interrupt. */
    isr_1_Disable();

    /* Set the ISR to point to the passive one. */
    isr_1_SetVector(IntDefaultHandler);
}

/*******************************************************************************
* Function Name: isr_1_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for isr_1.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(isr_1_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START isr_1_Interrupt` */

int16 scratch1 = 0; // The output to the VDAC is unsigned, but the data from the ADC is signed.
int16 scratch2 = 0;
uint8 scratch_translation = 0;
output_audio_val = 0x20003E81;

//********************************Update pointers****************************************************************
audio_circ_buffer_ptr_index += 1; // We do this extra step because the unary prefix isn't recognized by this dumb compiler
audio_circ_buffer_ptr_index = ((audio_circ_buffer_ptr_index)%16000); //Mod to keep track of wrap-around

echo_ptr_offset = (audio_circ_buffer_ptr_index + ECHO_POINTER_OFFSET_VALUE)%16000;
latest_input_val = 0x20000000u + audio_circ_buffer_ptr_index;
echo_data = 0x20000000u + echo_ptr_offset;
//***************************************************************************************************************
scratch1 |= CY_GET_REG8(latest_input_val);
if( (scratch1 & 0x0080)!= 0){
	scratch1 = scratch1 ^ 0x8000;
}

scratch2 |= CY_GET_REG8(echo_data);

if( (scratch2 & 0x0080)!= 0){
	scratch2 >> 1; //Halve the magnitude
	scratch2 = scratch1 ^ 0x8000;
}
else{
	scratch2 >> 1; //Halve the magnitude
}

scratch1 += scratch2;

scratch1 += 127; //Level shift as VDAC uses uint8, not singed int8

if(scratch1 > 255){
scratch1 = 255; //Saturation
}
else{
scratch1 &= 0x00FF; //Force to be 8 bit value
}
// For now we comment out the real thing and substitute a triangle wave
scratch_translation |= scratch1;

//ndex += 4;
//scratch_translation = ndex;


CY_SET_REG8(output_audio_val, scratch_translation);

CyDmaChSetRequest(DMA_3_Chan,CPU_REQ); //Assigned to scratch1 but we really don't care at this point

//VDAC8_1_SetValue(scratch_translation);

    /* `#END` */
}

/*******************************************************************************
* Function Name: isr_1_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt. Note calling isr_1_Start
*   will override any effect this method would have had. To set the vector before
*   the component has been started use isr_1_StartEx instead.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_1_SetVector(cyisraddress address) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + isr_1__INTC_NUMBER] = address;
}

/*******************************************************************************
* Function Name: isr_1_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress isr_1_GetVector(void) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + isr_1__INTC_NUMBER];
}

/*******************************************************************************
* Function Name: isr_1_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt. Note calling isr_1_Start
*   or isr_1_StartEx will override any effect this method would have had. 
*	This method should only be called after isr_1_Start or 
*	isr_1_StartEx has been called. To set the initial
*	priority for the component use the cydwr file in the tool.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_1_SetPriority(uint8 priority) 
{
    *isr_1_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: isr_1_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 isr_1_GetPriority(void) 
{
    uint8 priority;


    priority = *isr_1_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: isr_1_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_1_Enable(void) 
{
    /* Enable the general interrupt. */
    *isr_1_INTC_SET_EN = isr_1__INTC_MASK;
}

/*******************************************************************************
* Function Name: isr_1_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 isr_1_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return (*isr_1_INTC_SET_EN & isr_1__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: isr_1_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_1_Disable(void) 
{
    /* Disable the general interrupt. */
    *isr_1_INTC_CLR_EN = isr_1__INTC_MASK;
}

/*******************************************************************************
* Function Name: isr_1_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_1_SetPending(void) 
{
    *isr_1_INTC_SET_PD = isr_1__INTC_MASK;
}

/*******************************************************************************
* Function Name: isr_1_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void isr_1_ClearPending(void) 
{
    *isr_1_INTC_CLR_PD = isr_1__INTC_MASK;
}
